# Passerelle - uniform access to data and services
# Copyright (C) 2017  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import os
import sys
import zipfile
import tempfile
import fcntl
from optparse import make_option

from django.core.files.base import File
from django.core.management.base import BaseCommand, CommandError
from django.core.files.storage import DefaultStorage

from family.models import GenericFamily, Invoice


class Command(BaseCommand):
    option_list = BaseCommand.option_list + (
        make_option('-a', '--archive-file', dest='archive_file',
                    help="""Archive containing data files""",
                    default='exports_prcit.zip'
        ),
        make_option('-c', '--connector', dest='connector',
                    help="""Slug of the connector to import data into"""
        )
    )

    def handle(self, *args, **options):

        if not os.path.exists(options['archive_file']):
            raise CommandError('File %s does not exist.' % options['archive_file'])

        try:
            connector = GenericFamily.objects.get(slug=options['connector'])
        except GenericFamily.DoesNotExist:
            return

        storage = DefaultStorage()
        lock_filename = storage.path('family-%s/import-orleans-data.lock' % connector.id)
        try:
            fd = open(lock_filename, 'w')
            fcntl.lockf(fd, fcntl.LOCK_EX|fcntl.LOCK_NB)
        except IOError:
            raise CommandError('Command already running.')

        try:
            archive_name = os.path.basename(options['archive_file'])
            connector.archive.save(archive_name, File(file(options['archive_file'])))
        except Exception, e:
            raise CommandError('Error occured: %s' % e)
        finally:
            fd.close()
            os.unlink(lock_filename)
